AI-APPUI自动化测试平台

computer

### 本地端

devices

### 设备管理

phone_android

点击刷新获取设备

api

### API 配置

暂无配置
keyboard

### 输入法

Android
选择设备后查看输入法状态
folder_special

### 用例场景

暂无保存的场景
checklist

### 测试用例

全选 共 0 条，已选 0 条
playlist_add

添加或导入测试用例开始测试

timer 运行时长
00:00
speed 首Token
-
psychology 思考耗时
-
hourglass_bottom 总耗时
-
info 执行状态
待执行
article

等待执行任务...

history

暂无历史记录

description

暂无测试报告

screenshot_monitor

### 设备屏幕

phone_android

选择设备后显示

-

### 添加测试用例

用例名称
测试步骤（将作为AI指令执行）
预期结果（可选）

### 添加 API 配置

配置名称
Base URL
模型名称
API Key

### 保存为用例场景

场景名称

### 测试结果详情

warning

### 输入法未切换

请先切换到 ADB Keyboard 输入法

### touch_app 远程控制

0 FPS
phonelink

正在连接设备...